﻿using System;
using System.Collections.Generic;
using System.Linq;

using ScrumViewer.Models;
using ScrumViewer.Pages.LogIn;
using ScrumViewer.Services;


namespace ScrumViewer.Models { 

    public class StoryBoardService
    {
        private Models.StoryBoard storyBoard;
        private JsonFileService<UserStory> UserStoryJsonFileService;
        private JsonFileService<Task> TaskJsonFileService;

       

        public StoryBoardService(JsonFileService<UserStory> userStoryJsonFileService, JsonFileService<Task> taskJsonFileService)
        {
            UserStoryJsonFileService = userStoryJsonFileService;
            TaskJsonFileService = taskJsonFileService;

            storyBoard = MockData.MockStoryBoard.GetMockStoryBoard();
            
            //storyBoard = new StoryBoard(new CardNoGeneratorService());
            //List<UserStory> userStories = UserStoryJsonFileService.GetJsonObjects().ToList();
            //foreach (UserStory userStorey in userStories)
            //{
            //    storyBoard.AddCard(userStorey);
            //}

            //List<Task> tasks = TaskJsonFileService.GetJsonObjects().ToList();
            //foreach (Task task in tasks)
            //{
            //    storyBoard.AddCard(task);
            //}
            
        }

        public Models.StoryBoard GetStoryBoard()
        {
            return storyBoard;
        }

        public void SaveStoryBoard()
        {
            List<UserStory> userStories = new List<UserStory>();
            List<Task> tasks = new List<Task>();
            foreach (Card card in storyBoard.Cards)
            {
                if(card is UserStory) userStories.Add((UserStory)card);
                if(card is Task) tasks.Add((Task)card);
            }
            UserStoryJsonFileService.SaveJsonObjects(userStories);
            TaskJsonFileService.SaveJsonObjects(tasks);
        }

        public Card GetUserStory(string id)
        {

            foreach (Card card in storyBoard.Cards)
            {
                if (card.GetId() == id)
                    return card;
            }
            return null;
        }


       

        public void AddCard(Card card)
        {
            card.Creator = (TeamMember) LoginPageModel.LoggedInUser;//new TeamMember(1, "Henrik H", "heho", "1234", "Developer", "img/heho.jpg"); //todo to be fixed
            storyBoard.AddCard(card);
            SaveStoryBoard();
        }

        //public void AddTask(Task task)
        //{
        //    task.Creator = new TeamMember(1, "Henrik H", "heho", "1234", "Developer", "img/heho.jpg"); //todo to be fixed
        //    storyBoard.AddStory(task);
        //}

        public Card DeleteUserStory(string userstoryId)
        {
            Card userstoryToBeDeleted = GetUserStory(userstoryId);
            
            if (userstoryToBeDeleted != null)
            {
                storyBoard.Cards.Remove(userstoryToBeDeleted);
            }
            SaveStoryBoard();
            return userstoryToBeDeleted;
        }

        public void MoveUserStory(string id)
        {
            Card us = GetUserStory(id);
            storyBoard.MoveStory(us);
            SaveStoryBoard();
        }

        public void MoveBackUserStory(string id)
        {
            Card us = GetUserStory(id);
            storyBoard.MoveBackStory(us);
            SaveStoryBoard();
        }

        public void RedoUserStory(string id)
        {
            Card us = GetUserStory(id);
            storyBoard.RedoStory(us);
            SaveStoryBoard();
        }

    }
}
